Method: Scrivito::BasicWidget#container_attribute_name

Defined in:
app/cms/scrivito/basic_widget.rb,
app/cms/scrivito/basic_widget.rb

#container_attribute_nameString

Returns the name of the widgetlist attribute that references this widget.

Returns:

  • (String)

    the name of the attribute that references this widget.



327
328
329
# File 'app/cms/scrivito/basic_widget.rb', line 327

def container_attribute_name
  @container_attribute_name
end